Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
JLC2KiCadLib / JLC2KiCadLib.py |  | 45 | 22 | 0 |  | 51%
JLC2KiCadLib / __init__.py |  | 0 | 0 | 0 |  | 100%
JLC2KiCadLib / footprint / __init__.py |  | 0 | 0 | 0 |  | 100%
JLC2KiCadLib / footprint / footprint.py |  | 73 | 8 | 0 |  | 89%
JLC2KiCadLib / footprint / footprint_handlers.py |  | 265 | 25 | 0 |  | 91%
JLC2KiCadLib / footprint / model3d.py |  | 106 | 13 | 0 |  | 88%
JLC2KiCadLib / helper.py |  | 13 | 10 | 0 |  | 23%
JLC2KiCadLib / symbol / __init__.py |  | 0 | 0 | 0 |  | 100%
JLC2KiCadLib / symbol / symbol.py |  | 76 | 4 | 0 |  | 95%
JLC2KiCadLib / symbol / symbol_handlers.py |  | 156 | 5 | 0 |  | 97%
Total |  | 734 | 87 | 0 |  | 88%

No items found using the specified filter.